@@ -80,6 +80,7 @@ class SnowflakeExtractor(BaseExtractor):
                 self._fetch_primary_keys(cursor, database)
                 self._fetch_unique_keys(cursor, database)
                 self._fetch_table_info(conn, tables)
+                self._fetch_tags(cursor)
 
         logger.debug(self._datasets)
 
@@ -269,6 +270,34 @@ class SnowflakeExtractor(BaseExtractor):
                 sql_schema.primary_key = []
             sql_schema.primary_key.append(column)
 
+    def _fetch_tags(self, cursor: SnowflakeCursor) -> None:
+        cursor.execute(
+            """
+            SELECT TAG_NAME, TAG_VALUE, OBJECT_DATABASE, OBJECT_SCHEMA, OBJECT_NAME
+            FROM snowflake.account_usage.tag_references
+            WHERE domain = 'TABLE'
+            ORDER BY OBJECT_DATABASE, OBJECT_SCHEMA, OBJECT_NAME
+            """
+        )
+
+        for key, value, database, schema, table_name in cursor:
+            table = dataset_fullname(database, schema, table_name)
+
+            dataset = self._datasets.get(table)
+            if dataset is None or dataset.schema is None:
+                logger.error(
+                    f"Table {table} not found for tag {self._build_tag_string(key, value)}"
+                )
+                continue
+
+            if not dataset.schema.tags:
+                dataset.schema.tags = []
+            dataset.schema.tags.append(self._build_tag_string(key, value))
+
+    @staticmethod
+    def _build_tag_string(tag_key: str, tag_value: str) -> str:
+        return f"{tag_key}={tag_value}"
+
     def _init_dataset(
         self,
         full_name: str,
